@@ -180,6 +180,11 @@ def django_instance_field_to_redis_value(
             )
             for django_many_to_many_instance in django_field_value.all()
         ]
+    elif django_field.__class__.__name__.endswith('File'):
+        try:
+            redis_value = django_field_value.path
+        except:
+            print(django_field.__class__.__name__, django_field_value.__dict__)
     return redis_value
 
 
@@ -191,15 +196,12 @@ def django_instance_to_redis_params(
     redis_params = {}
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
         if not django_field.__class__.__name__.endswith('Rel'):
-            print()
-            print(django_field, django_field.__class__.__name__)
             redis_param = django_instance_field_to_redis_value(
                 django_instance,
                 django_field,
                 redis_root,
                 create_redis_model_from_django_model
             )
-            print(django_field.name, redis_param)
             redis_params[django_field.name] = redis_param
     return redis_params
 
