@@ -448,7 +448,7 @@ class RedisRoot:
                 for model in redis_root.registered_models:
                     print()
                     print(model)
-                    print(model.__model_data__['fields'])
+                    print(model.__dict__)
 
                 return new_redis_model
             
